==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/testhelper/mock_mobilitydbcsv.go <==
package testhelper

import (
	"fmt"
	"log"
	"os"
)

// PrepareMockMobilityDBMockFromGTFSYML prepares a mock Mobility DB CSV
// that references a dynamically created GTFS zip mock from the input YML
// file passed as param. The output CSV can be treated as a input for Mobsql
// etc. in place of where Mobsql typical ingests the Mobility CSV from
// Mobility DB's bit.ly upstream URL.
//
// The YML file input is structured in a way to simply and concisely
// represent GTFS for the purpose of mocking out tests. The top level
// key is the ZIP archive contents filename, and each value is an array
// of object values that will be converted to CSV entries in the DB mock.
//
// Example YML input file might look like:
//
//	agency.txt:
//	  - {agency_id: fooagency, agency_name: foo agency, agency_url: http://foo.com}
//
//	stops.txt:
//	  - { stop_id: 101, stop_name: "foostop", stop_lat: 40.889248, stop_lon: -73.898583, parent_station: 101N }
//	  - { stop_id: 101N, stop_name: "foostop", stop_lat: 40.889248, stop_lon: -73.898583, parent_station: 101 }
//
//	stop_times.txt:
//	  - { trip_id: trip_wk_foo_up, stop_id: 101N, stop_sequence: 1, arrival_time: 00:06:00, departure_time: 00:06:00 }
//	  - { trip_id: trip_wk_foo_up, stop_id: 101N, stop_sequence: 3, arrival_time: 00:07:00, departure_time: 00:07:00 }
func PrepareMockMobilityDBMockFromGTFSYMLs(
	mapSourceIDToYMLSpecfilepath map[int]string,
) (string, []string, error) {
	var (
		mobdbCSV        *os.File
		gtfsZipFilepath string
		err             error
	)

	gtfsZips := []string{}
	mdb := []map[string]any{}
	for sourceID, ymlSpec := range mapSourceIDToYMLSpecfilepath {
		if gtfsZipFilepath, err = YMLToCSVZip(ymlSpec); err != nil {
			return "", nil, fmt.Errorf("Failed to create mock GTFS Feed file: %v", err)
		} else {
			gtfsZips = append(gtfsZips, gtfsZipFilepath)
			mdb = append(mdb, map[string]any{
				"data_type":                               "gtfs",
				"location.bounding_box.minimum_latitude":  "40.512764",
				"location.bounding_box.minimum_longitude": "-74.251961",
				"location.bounding_box.maximum_latitude":  "40.903125",
				"location.bounding_box.maximum_longitude": "-73.755405",
				"location.country_code":                   "FOO",
				"location.subdivision_name":               "BAR",
				"location.municipality":                   "BIZ",
				"urls.latest":                             fmt.Sprintf("file://%s", gtfsZipFilepath), // E.g. generated
				"mdb_source_id":                           sourceID,
				"name":                                    fmt.Sprintf("Mock GTFS feed %d", sourceID),
				"status":                                  "active",
				"provider":                                fmt.Sprintf("Mock provider %d", sourceID),
			})
		}
	}

	if mobdbCSV, err = os.CreateTemp("", "mobroute_test_mobdb_*.csv"); err != nil {
		return "", nil, fmt.Errorf("Failed to create SQLite DB: %v", err)
	} else if ArrayOfMapsToCSV(mdb, mobdbCSV.Name()); err != nil {
		return "", nil, fmt.Errorf("Failed to populate mock mobility DB CSV: %v", err)
	} else {
		log.Printf(
			"Generated mock: (gtfs zips: %v) (mobdb csv: %v)",
			gtfsZips, mobdbCSV.Name(),
		)
		return mobdbCSV.Name(), gtfsZips, nil
	}
}

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/testhelper/mock_mobilitydbcsv.go <==
package testhelper

import (
	"fmt"
	"log"
	"os"
)

// PrepareMockMobilityDBMockFromGTFSYML prepares a mock Mobility DB CSV
// that references a dynamically created GTFS zip mock from the input YML
// file passed as param. The output CSV can be treated as a input for Mobsql
// etc. in place of where Mobsql typical ingests the Mobility CSV from
// Mobility DB's bit.ly upstream URL.
//
// The YML file input is structured in a way to simply and concisely
// represent GTFS for the purpose of mocking out tests. The top level
// key is the ZIP archive contents filename, and each value is an array
// of object values that will be converted to CSV entries in the DB mock.
//
// Example YML input file might look like:
//
//	agency.txt:
//	  - {agency_id: fooagency, agency_name: foo agency, agency_url: http://foo.com}
//
//	stops.txt:
//	  - { stop_id: 101, stop_name: "foostop", stop_lat: 40.889248, stop_lon: -73.898583, parent_station: 101N }
//	  - { stop_id: 101N, stop_name: "foostop", stop_lat: 40.889248, stop_lon: -73.898583, parent_station: 101 }
//
//	stop_times.txt:
//	  - { trip_id: trip_wk_foo_up, stop_id: 101N, stop_sequence: 1, arrival_time: 00:06:00, departure_time: 00:06:00 }
//	  - { trip_id: trip_wk_foo_up, stop_id: 101N, stop_sequence: 3, arrival_time: 00:07:00, departure_time: 00:07:00 }
func PrepareMockMobilityDBMockFromGTFSYMLs(
	mapFeedIDToYMLSpecfilepath map[int]string,
) (string, []string, error) {
	var (
		mobdbCSV        *os.File
		gtfsZipFilepath string
		err             error
	)

	gtfsZips := []string{}
	mdb := []map[string]any{}
	for feedID, ymlSpec := range mapFeedIDToYMLSpecfilepath {
		if gtfsZipFilepath, err = YMLToCSVZip(ymlSpec); err != nil {
			return "", nil, fmt.Errorf("Failed to create mock GTFS Feed file: %v", err)
		} else {
			gtfsZips = append(gtfsZips, gtfsZipFilepath)
			mdb = append(mdb, map[string]any{
				"data_type":                               "gtfs",
				"location.bounding_box.minimum_latitude":  "40.512764",
				"location.bounding_box.minimum_longitude": "-74.251961",
				"location.bounding_box.maximum_latitude":  "40.903125",
				"location.bounding_box.maximum_longitude": "-73.755405",
				"location.country_code":                   "FOO",
				"location.subdivision_name":               "BAR",
				"location.municipality":                   "BIZ",
				"urls.latest":                             fmt.Sprintf("file://%s", gtfsZipFilepath), // E.g. generated
				"mdb_source_id":                           feedID,
				"name":                                    fmt.Sprintf("Mock GTFS feed %d", feedID),
				"status":                                  "active",
				"provider":                                fmt.Sprintf("Mock provider %d", feedID),
			})
		}
	}

	if mobdbCSV, err = os.CreateTemp("", "mobroute_test_mobdb_*.csv"); err != nil {
		return "", nil, fmt.Errorf("Failed to create SQLite DB: %v", err)
	} else if ArrayOfMapsToCSV(mdb, mobdbCSV.Name()); err != nil {
		return "", nil, fmt.Errorf("Failed to populate mock mobility DB CSV: %v", err)
	} else {
		log.Printf(
			"Generated mock for input (%v): (gtfs zips: %v) (mobdb csv: %v)",
			mapFeedIDToYMLSpecfilepath,
			gtfsZips, mobdbCSV.Name(),
		)
		return mobdbCSV.Name(), gtfsZips, nil
	}
}
